@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2021, Oracle and/or its affiliates.
+ * Copyright (c) 2002, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License, version 2.0, as published by the
@@ -993,7 +993,7 @@ public abstract class BaseTestCase {
     protected static void assertSecureConnection(Connection conn) throws Exception {
         try (Statement stmt = conn.createStatement(); ResultSet rs = stmt.executeQuery("SHOW STATUS LIKE 'Ssl_version'")) {
             assertTrue(rs.next());
-            assertNotEquals("", rs.getString(1));
+            assertNotEquals("", rs.getString(2));
         }
     }
 
@@ -1005,6 +1005,13 @@ public abstract class BaseTestCase {
         }
     }
 
+    protected static void assertNonSecureConnection(Connection conn) throws Exception {
+        try (Statement stmt = conn.createStatement(); ResultSet rs = stmt.executeQuery("SHOW STATUS LIKE 'Ssl_version'")) {
+            assertTrue(rs.next());
+            assertEquals("", rs.getString(2));
+        }
+    }
+
     /*
      * Set default values for primitives. (prevents NPE in Java 1.4 when calling via reflection)
      */
